# the shorewall release numbers split into two parts
%define majorrelease 5.2.1
%define updaterelease 4
# rpmrelease is appended if betarelease != 0, otherwise becomes release
%define rpmrelease 1
# betarelease is either 0 or something like RC1
%define betarelease 0

# old systems have Digest::SHA1 instead of Digest::SHA
%define digest_sha SHA1
%{!?digest_sha: %define digest_sha SHA}

# systemd options
%define _has_systemd %(eval rpm -q --quiet systemd && rpm -q --queryformat '%{VERSION}\\n' systemd || echo 0)
%if %{_has_systemd}
  %define _servicefile_postfix %{_has_systemd}.service.in
%else
  %define _servicefile_postfix init
%endif

%define gitname Shorewall
%if %{updaterelease}
%define sourceversion %{majorrelease}.%{updaterelease}
%else
%define sourceversion %{majorrelease}
%endif
%if %{betarelease}
%define downloaddir http://www.shorewall.org/pub/shorewall/development/%{majorrelease}/shorewall-%{version}-%{betarelease}/base
%define longver %{sourceversion}-%{betarelease}
%else
%define downloaddir http://www.shorewall.org/pub/shorewall/%{majorrelease}/shorewall-%{version}/base
%define longver %{sourceversion}
%endif

Name: shorewall
Version: %{majorrelease}.%{updaterelease}
%if %{betarelease}
Release: 0.%{betarelease}_%{rpmrelease}%{?dist}
%else
Release: %{rpmrelease}%{?dist}
%endif
Summary: Shoreline Firewall is an iptables-based firewall for Linux systems
Source0: %{downloaddir}/%{name}-%{longver}.tar.bz2
Source1: %{downloaddir}/%{name}-lite-%{longver}.tar.bz2
Source2: %{downloaddir}/%{name}6-%{longver}.tar.bz2
Source3: %{downloaddir}/%{name}6-lite-%{longver}.tar.bz2
Source4: %{downloaddir}/%{name}-init-%{longver}.tar.bz2
Source5: %{downloaddir}/%{name}-core-%{longver}.tar.bz2
# service/init file for all sub-packages except shorewall-init
Source6: %{name}.%{_servicefile_postfix}
# service/init file for shorewall-init
Source7: %{name}-init.%{_servicefile_postfix}
# errata files
#Source100: %{downloaddir}/errata/Shorewall/compiler
#Source100: %{downloaddir}/errata/Shorewall-lite/shorewall.conf
Patch0: shorewall-5.0.4-install_preserve_timestamps.patch
Patch1: shorewall-4.5.5-logrotate.patch
# patches => 100 should/will be fixed in SCM
#Patch101: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-4.5.0.1
#Patch201: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-lite-4.5.0.1
#Patch301: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-6-4.5.0.1
#Patch401: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-6-lite-4.5.0.1
#Patch501: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-init-4.5.0.1
#Patch601: ftp://ftp.shorewall.org/pub/shorewall/4.5/shorewall-4.5.0/patch-core-4.5.0.1
URL: http://www.shorewall.org/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
License: GPLv2
Group: Applications/System
BuildArch: noarch
AutoReqProv: No
Provides: %{name}(firewall) = %{version}-%{release}
Requires: %{name}-core = %{version}-%{release}
Requires: iptables, iproute, /etc/redhat-release
Requires: bash, bc, logrotate, perl, perl(Digest::%{digest_sha})
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif
BuildRequires: sed, perl
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Obsoletes: %{name}-shell, %{name}-perl

%description
The Shoreline Firewall, more commonly known as Shorewall, is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/router/server or on a standalone GNU/Linux system.

%package lite
Group: Applications/System
Summary: Shoreline Firewall Lite is an iptables-based firewall for Linux systems
AutoReqProv: No
Provides: %{name}(firewall) = %{version}-%{release}
Requires: %{name}-core = %{version}-%{release}
Requires: iptables, iproute, /etc/redhat-release
Requires: bash, bc
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

%description lite
The Shoreline Firewall, more commonly known as Shorewall, is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/router/server or on a standalone GNU/Linux system.

Shorewall Lite is a companion product to Shorewall that allows network
administrators to centralize the configuration of Shorewall-based firewalls.

%package -n %{name}6
Group: Applications/System
Summary: Shoreline Firewall 6 is an iptables-based firewall for Linux systems
AutoReqProv: No
Provides: %{name}(firewall) = %{version}-%{release}
Requires: %{name} = %{version}-%{release}
Requires: iptables-ipv6, /etc/redhat-release
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

%description -n %{name}6
The Shoreline Firewall 6, more commonly known as Shorewall6, is a Netfilter
(ip6tables) based IPv6 firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package -n %{name}6-lite
Group: Applications/System
Summary: Shoreline Firewall 6 Lite is an ip6tables-based firewall for Linux systems
AutoReqProv: No
Provides: %{name}(firewall) = %{version}-%{release}
Requires: %{name}-core = %{version}-%{release}
Requires: iptables-ipv6, iproute, /etc/redhat-release
Requires: bash, bc
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

%description -n %{name}6-lite
The Shoreline Firewall 6, more commonly known as Shorewall6, is a Netfilter
(ip6tables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

Shorewall6 Lite is a companion product to Shorewall6 that allows network
administrators to centralize the configuration of Shorewall6-based firewalls.

%package -n %{name}-init
Group: Applications/System
Summary: Initialization functionality and NetworkManager integration for Shorewall
AutoReqProv: No
Requires: %{name}(firewall) = %{version}-%{release}
Requires: %{name} = %{version}-%{release}
Requires: NetworkManager
%if %{_has_systemd}
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

%description -n %{name}-init
This package adds additional initialization functionality to Shorewall in
two ways. It allows the firewall to be closed prior to bringing up network
devices. This insures that unwanted connections are not allowed between
the time that the network comes up and when the firewall is started. It
also integrates with NetworkManager and distribution ifup/ifdown systems
to allow for event-driven startup and shutdown.

%package -n %{name}-core
Group: Applications/System
Summary: Core libraries for Shorewall
AutoReqProv: No

%description -n %{name}-core
This package contains the core libraries for Shorewall.

%prep
%setup -q -n %{name}-%{longver} -c -a1 -a2 -a3 -a4 -a5

# add links so we can apply patches from SCM
%{__ln_s} %{name}-%{longver}         %{gitname}
%{__ln_s} %{name}-lite-%{longver}    %{gitname}-lite
%{__ln_s} %{name}6-%{longver}        %{gitname}6
%{__ln_s} %{name}6-lite-%{longver}   %{gitname}6-lite
%{__ln_s} %{name}-init-%{longver}    %{gitname}-init
%{__ln_s} %{name}-core-%{longver}    %{gitname}-core

# errata files
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}-%{longver}/
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}-lite-%{longver}/
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}6-%{longver}/
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}6-lite-%{longver}/
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}-init-%{longver}/
#%{__install} -m 0755 -p %{SOURCE100} ./%{name}-core-%{longver}/

# patches from SCM
# apply patches to shorewall
pushd %{name}-%{longver}
  #%patch101 -p1
popd

# apply patches to shorewall-lite
pushd %{name}-lite-%{longver}
  #%patch201 -p1
popd

# apply patches to shorewall6
pushd %{name}6-%{longver}
  #%patch301 -p1
popd

# apply patches to shorewall6-lite
pushd %{name}6-lite-%{longver}
  #%patch401 -p1
popd

# apply patches to shorewall-init
pushd %{name}-init-%{longver}
  #%patch501 -p1
popd

# apply patches to shorewall-core
pushd %{name}-core-%{longver}
  #%patch601 -p1
popd

# patches from Invoca
%patch0 -p0
%patch1 -p0

# fix permissions
find . -type f -exec %{__chmod} 0644 {} \;

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

# core must be installed first
pushd %{name}-core-%{longver}
  %{__perl} configure.pl \
    --prefix=%{_prefix} \
    --sharedir=%{_datadir} \
    --libexecdir=%{_libexecdir} \
    --perllibdir=%{perl_vendorlib} \
    --sbindir=%{_sbindir} \
    --mandir=%{_mandir} \
%if %{_has_systemd}
    --initfile= \
    --servicedir=%{_unitdir} \
%else
    --initdir=%{_initrddir} \
    --initsource=init.sh \
    --servicedir= \
%endif
    --sysconffile=sysconfig \
    --varlib=%{_var}/lib \
    --vendor=redhat
  DESTDIR=%{buildroot} DIGEST=%{digest_sha} %{_buildshell} install.sh
popd

pushd %{name}-%{longver}
  DESTDIR=%{buildroot} %{_buildshell} install.sh %{buildroot}%{_datadir}/%{name}/%{name}rc
popd
pushd %{name}-lite-%{longver}
  DESTDIR=%{buildroot} %{_buildshell} install.sh %{buildroot}%{_datadir}/%{name}/%{name}rc
popd
pushd %{name}6-%{longver}
  DESTDIR=%{buildroot} %{_buildshell} install.sh %{buildroot}%{_datadir}/%{name}/%{name}rc
popd
pushd %{name}6-lite-%{longver}
  DESTDIR=%{buildroot} %{_buildshell} install.sh %{buildroot}%{_datadir}/%{name}/%{name}rc
popd
pushd %{name}-init-%{longver}
  DESTDIR=%{buildroot} %{_buildshell} install.sh %{buildroot}%{_datadir}/%{name}/%{name}rc
popd

# install service/init files
%if %{_has_systemd}
%{__sed} -e "s@__IPTABLES__@iptables@g" \
         -e "s@__PRODUCT__@%{name}@g" \
         -e "s@__AFTER__@@g" \
  %{SOURCE6} > %{buildroot}%{_unitdir}/%{name}.service
%{__sed} -e "s@__IPTABLES__@iptables@g" \
         -e "s@__PRODUCT__@%{name} -l@g" \
         -e "s@__AFTER__@@g" \
  %{SOURCE6} > %{buildroot}%{_unitdir}/%{name}-lite.service
%{__sed} -e "s@__IPTABLES__@ip6tables@g" \
         -e "s@__PRODUCT__@%{name} -6@g" \
         -e "s@__AFTER__@ %{name}.service@g" \
  %{SOURCE6} > %{buildroot}%{_unitdir}/%{name}6.service
%{__sed} -e "s@__IPTABLES__@ip6tables@g" \
         -e "s@__PRODUCT__@%{name} -6l@g" \
         -e "s@__AFTER__@ %{name}-lite.service@g" \
  %{SOURCE6} > %{buildroot}%{_unitdir}/%{name}6-lite.service
%{__install} -m 0644 -p %{SOURCE7} %{buildroot}%{_unitdir}/%{name}-init.service
%else
%{__install} -m 0755 -p %{SOURCE6} %{buildroot}%{_initrddir}/%{name}
%{__install} -m 0755 -p %{SOURCE6} %{buildroot}%{_initrddir}/%{name}-lite
%{__install} -m 0755 -p %{SOURCE6} %{buildroot}%{_initrddir}/%{name}6
%{__install} -m 0755 -p %{SOURCE6} %{buildroot}%{_initrddir}/%{name}6-lite
%{__install} -m 0755 -p %{SOURCE7} %{buildroot}%{_initrddir}/%{name}-init
%endif

# errata files
#%{__install} -m 0600 -p %{SOURCE100} %{buildroot}%{_datadir}/%{name}/
#%{__install} -m 0600 -p %{SOURCE100} %{buildroot}%{_sysconfdir}/%{name}/
#%{__install} -m 0600 -p %{SOURCE100} %{buildroot}%{_sysconfdir}/%{name}-lite/
#%{__install} -m 0600 -p %{SOURCE100} %{buildroot}%{_sbindir}/

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/chkconfig --del %{name}
fi
%endif

%post lite
%if %{_has_systemd}
%systemd_post %{name}-lite.service
%else
/sbin/chkconfig --add %{name}-lite
%endif

%preun lite
%if %{_has_systemd}
%systemd_preun %{name}-lite.service
%else
if [ $1 -eq 0 ]; then
  /sbin/chkconfig --del %{name}-lite
fi
%endif

%post -n %{name}6
%if %{_has_systemd}
%systemd_post %{name}6.service
%else
/sbin/chkconfig --add %{name}6
%endif

%preun -n %{name}6
%if %{_has_systemd}
%systemd_preun %{name}6.service
%else
if [ $1 -eq 0 ]; then
  /sbin/chkconfig --del %{name}6
fi
%endif

%post -n %{name}6-lite
%if %{_has_systemd}
%systemd_post %{name}6-lite.service
%else
/sbin/chkconfig --add %{name}6-lite
%endif

%preun -n %{name}6-lite
%if %{_has_systemd}
%systemd_preun %{name}6-lite.service
%else
if [ $1 -eq 0 ]; then
  /sbin/chkconfig --del %{name}6-lite
fi
%endif

%post init
%if %{_has_systemd}
%systemd_post %{name}-init.service
%else
/sbin/chkconfig --add %{name}-init
%endif

%preun init
%if %{_has_systemd}
%systemd_preun %{name}-init.service
%else
if [ $1 -eq 0 ]; then
  /sbin/chkconfig --del %{name}-init
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{longver}/COPYING
%doc %{name}-%{longver}/INSTALL
%doc %{name}-%{longver}/changelog.txt
%doc %{name}-%{longver}/releasenotes.txt
%doc %{name}-%{longver}/Samples
%doc %{name}-%{longver}/Contrib
%{_mandir}/man5/%{name}-[a-k,m-z]*.5*
%{_mandir}/man5/%{name}-logging.5*
%{_mandir}/man5/%{name}.conf.5*
%if %{_has_systemd}
%attr(0644,root,root) %{_unitdir}/%{name}.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}
%endif
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/params
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/[a-o,q-r,t-z]*
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/policy
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/pro*
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/scfilter
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/secmarks
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/snat
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}/st*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(0755,root,root) %dir %{_datadir}/%{name}
%attr(0644,root,root) %{_datadir}/%{name}/[a,h,m-p,v]*
%attr(0644,root,root) %{_datadir}/%{name}/lib.cli-std
%attr(0644,root,root) %{_datadir}/%{name}/lib.runtime
%attr(0644,root,root) %{_datadir}/%{name}/configpath
%attr(0755,root,root) %dir %{_datadir}/%{name}/configfiles
%attr(0644,root,root) %{_datadir}/%{name}/configfiles/*
%attr(0755,root,root) %dir %{_libexecdir}/%{name}
%attr(0755,root,root) %{_libexecdir}/%{name}/compiler.pl
%attr(0755,root,root) %{_libexecdir}/%{name}/getparams
%attr(0755,root,root) %dir %{perl_vendorlib}/Shorewall
%attr(0644,root,root) %{perl_vendorlib}/Shorewall/*
%attr(0700,root,root) %dir %{_var}/lib/%{name}

%files lite
%defattr(-,root,root,-)
%doc %{name}-lite-%{longver}/COPYING
%doc %{name}-lite-%{longver}/changelog.txt
%doc %{name}-lite-%{longver}/releasenotes.txt
%{_mandir}/man5/%{name}-lite*.5*
%{_mandir}/man8/%{name}-lite.8*
%{_sbindir}/%{name}-lite
%if %{_has_systemd}
%attr(0644,root,root) %{_unitdir}/%{name}-lite.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}-lite
%endif
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}-lite
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}-lite
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}-lite/[a-z]*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-lite
%attr(0755,root,root) %dir %{_datadir}/%{name}-lite
%attr(0644,root,root) %{_datadir}/%{name}-lite/[c,h-v]*
%{_datadir}/%{name}-lite/functions
%attr(0755,root,root) %dir %{_libexecdir}/%{name}-lite
%attr(0755,root,root) %{_libexecdir}/%{name}-lite/shorecap
%attr(0700,root,root) %dir %{_var}/lib/%{name}-lite

%files -n %{name}6
%defattr(-,root,root,-)
%doc %{name}6-%{longver}/COPYING
%doc %{name}6-%{longver}/INSTALL
%doc %{name}6-%{longver}/changelog.txt
%doc %{name}6-%{longver}/releasenotes.txt
%doc %{name}6-%{longver}/tunnel
%doc %{name}6-%{longver}/ipsecvpn
%doc %{name}6-%{longver}/Samples6
%{_mandir}/man5/%{name}6-[a-k,m-z]*.5*
%{_mandir}/man5/%{name}6.conf.5*
%{_mandir}/man8/%{name}6.8*
%{_sbindir}/%{name}6
%if %{_has_systemd}
%attr(0644,root,root) %{_unitdir}/%{name}6.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}6
%endif
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}6
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}6
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/params
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/%{name}6.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/[a-o,q-r,t-z]*
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/policy
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/pro*
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/scfilter
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/secmarks
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/snat
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}6/st*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}6
%attr(0755,root,root) %dir %{_datadir}/%{name}6
%attr(0644,root,root) %{_datadir}/%{name}6/[a,h-v,A-Z]*
%{_datadir}/%{name}6/functions
%attr(0644,root,root) %{_datadir}/%{name}6/configpath
%attr(0755,root,root) %dir %{_datadir}/%{name}6/configfiles
%attr(0644,root,root) %{_datadir}/%{name}6/configfiles/*
%attr(0755,root,root) %dir %{_libexecdir}/%{name}6
%attr(0700,root,root) %dir %{_var}/lib/%{name}6

%files -n %{name}6-lite
%defattr(-,root,root,-)
%doc %{name}6-lite-%{longver}/COPYING
%doc %{name}6-lite-%{longver}/changelog.txt
%doc %{name}6-lite-%{longver}/releasenotes.txt
%{_mandir}/man5/%{name}6-lite*.5*
%{_mandir}/man8/%{name}6-lite.8*
%{_sbindir}/%{name}6-lite
%if %{_has_systemd}
%attr(0644,root,root) %{_unitdir}/%{name}6-lite.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}6-lite
%endif
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}6-lite
%attr(0755,root,root) %dir %{_sysconfdir}/%{name}6-lite
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/%{name}6-lite/[a-z]*
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}6-lite
%attr(0755,root,root) %dir %{_datadir}/%{name}6-lite
%attr(0644,root,root) %{_datadir}/%{name}6-lite/[c,h-v]*
%{_datadir}/%{name}6-lite/functions
%attr(0755,root,root) %dir %{_libexecdir}/%{name}6-lite
%attr(0755,root,root) %{_libexecdir}/%{name}6-lite/shorecap
%attr(0700,root,root) %dir %{_var}/lib/%{name}6-lite

%files init
%defattr(-,root,root,-)
%doc %{name}-init-%{longver}/COPYING
%doc %{name}-init-%{longver}/changelog.txt
%doc %{name}-init-%{longver}/releasenotes.txt
%{_mandir}/man8/%{name}-init.8*
%if %{_has_systemd}
%attr(0644,root,root) %{_unitdir}/%{name}-init.service
%attr(0755,root,root) %{_sbindir}/%{name}-init
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}-init
%endif
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}-init
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-init
%attr(0755,root,root) %{_sysconfdir}/NetworkManager/dispatcher.d/01-%{name}
%attr(0755,root,root) %dir %{_libexecdir}/%{name}-init
%attr(0755,root,root) %{_libexecdir}/%{name}-init/ifupdown
%{_datadir}/%{name}-init/version

%files core
%defattr(-,root,root,-)
%doc %{name}-core-%{longver}/COPYING
%doc %{name}-core-%{longver}/changelog.txt
%doc %{name}-core-%{longver}/releasenotes.txt
%{_mandir}/man8/%{name}.8*
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0755,root,root) %dir %{_datadir}/%{name}
%attr(0644,root,root) %{_datadir}/%{name}/coreversion
%{_datadir}/%{name}/functions
%attr(0644,root,root) %{_datadir}/%{name}/lib.base
%attr(0644,root,root) %{_datadir}/%{name}/lib.cli
%attr(0644,root,root) %{_datadir}/%{name}/lib.common
%attr(0644,root,root) %{_datadir}/%{name}/lib.core
%attr(0644,root,root) %{_datadir}/%{name}/shorewallrc
%attr(0755,root,root) %dir %{_libexecdir}/%{name}
%attr(0755,root,root) %{_libexecdir}/%{name}/wait4ifup

%changelog
* Mon Dec 17 2018 Simon Matter <simon.matter@invoca.ch> 5.2.1.4-1
- upgrade to release 5.2.1.4

* Thu Dec 13 2018 Simon Matter <simon.matter@invoca.ch> 5.2.1.3-1
- upgrade to release 5.2.1.3

* Thu Nov 29 2018 Simon Matter <simon.matter@invoca.ch> 5.2.1.2-1
- upgrade to release 5.2.1.2

* Mon Oct 29 2018 Simon Matter <simon.matter@invoca.ch> 5.2.1.1-1
- upgrade to release 5.2.1.1

* Wed Oct 03 2018 Simon Matter <simon.matter@invoca.ch> 5.2.1.0-1
- upgrade to release 5.2.1

* Mon Aug 06 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.5-1
- upgrade to release 5.2.0.5

* Mon May 21 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.4-1
- upgrade to release 5.2.0.4

* Mon May 14 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.3-1
- upgrade to release 5.2.0.3

* Mon May 07 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.2-1
- upgrade to release 5.2.0.2

* Sat Apr 28 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.1-1
- upgrade to release 5.2.0.1

* Thu Apr 12 2018 Simon Matter <simon.matter@invoca.ch> 5.2.0.0-1
- upgrade to release 5.2.0

* Fri Mar 02 2018 Simon Matter <simon.matter@invoca.ch> 5.1.12.3-1
- upgrade to release 5.1.12.3

* Thu Feb 22 2018 Simon Matter <simon.matter@invoca.ch> 5.1.12.2-1
- upgrade to release 5.1.12.2

* Sat Feb 10 2018 Simon Matter <simon.matter@invoca.ch> 5.1.12.1-1
- upgrade to release 5.1.12.1

* Fri Feb 09 2018 Simon Matter <simon.matter@invoca.ch> 5.1.12.0-1
- upgrade to release 5.1.12

* Mon Jan 29 2018 Simon Matter <simon.matter@invoca.ch> 5.1.11.2-1
- upgrade to release 5.1.11.2

* Sat Jan 20 2018 Simon Matter <simon.matter@invoca.ch> 5.1.11.1-1
- upgrade to release 5.1.11.1

* Thu Jan 18 2018 Simon Matter <simon.matter@invoca.ch> 5.1.11.0-1
- upgrade to release 5.1.11

* Tue Jan 02 2018 Simon Matter <simon.matter@invoca.ch> 5.1.10.2-1
- upgrade to release 5.1.10.2

* Fri Dec 29 2017 Simon Matter <simon.matter@invoca.ch> 5.1.10.1-1
- upgrade to release 5.1.10.1

* Wed Dec 27 2017 Simon Matter <simon.matter@invoca.ch> 5.1.10.0-1
- upgrade to release 5.1.10

* Mon Nov 27 2017 Simon Matter <simon.matter@invoca.ch> 5.1.9.0-1
- upgrade to release 5.1.9

* Thu Nov 09 2017 Simon Matter <simon.matter@invoca.ch> 5.1.8.1-1
- upgrade to release 5.1.8.1

* Mon Oct 23 2017 Simon Matter <simon.matter@invoca.ch> 5.1.8.0-1
- upgrade to release 5.1.8

* Sat Sep 30 2017 Simon Matter <simon.matter@invoca.ch> 5.1.7.2-1
- upgrade to release 5.1.7.2

* Mon Sep 25 2017 Simon Matter <simon.matter@invoca.ch> 5.1.7.1-1
- upgrade to release 5.1.7.1

* Tue Sep 19 2017 Simon Matter <simon.matter@invoca.ch> 5.1.7.0-1
- upgrade to release 5.1.7

* Thu Aug 31 2017 Simon Matter <simon.matter@invoca.ch> 5.1.6.1-1
- upgrade to release 5.1.6.1

* Wed Aug 23 2017 Simon Matter <simon.matter@invoca.ch> 5.1.6.0-1
- upgrade to release 5.1.6

* Wed Aug 02 2017 Simon Matter <simon.matter@invoca.ch> 5.1.5.2-1
- upgrade to release 5.1.5.2

* Sat Jul 22 2017 Simon Matter <simon.matter@invoca.ch> 5.1.5.1-1
- upgrade to release 5.1.5.1

* Wed Jun 28 2017 Simon Matter <simon.matter@invoca.ch> 5.1.5.0-1
- upgrade to release 5.1.5

* Sat Jun 24 2017 Simon Matter <simon.matter@invoca.ch> 5.1.4.4-1
- upgrade to release 5.1.4.4

* Tue Jun 20 2017 Simon Matter <simon.matter@invoca.ch> 5.1.4.3-1
- upgrade to release 5.1.4.3

* Tue Jun 13 2017 Simon Matter <simon.matter@invoca.ch> 5.1.4.2-1
- upgrade to release 5.1.4.2

* Mon May 29 2017 Simon Matter <simon.matter@invoca.ch> 5.1.4.1-1
- upgrade to release 5.1.4.1

* Mon May 08 2017 Simon Matter <simon.matter@invoca.ch> 5.1.4.0-1
- upgrade to release 5.1.4

* Mon Mar 27 2017 Simon Matter <simon.matter@invoca.ch> 5.1.3.2-1
- upgrade to release 5.1.3.2

* Fri Mar 17 2017 Simon Matter <simon.matter@invoca.ch> 5.1.3.1-1
- upgrade to release 5.1.3.1

* Wed Mar 15 2017 Simon Matter <simon.matter@invoca.ch> 5.1.3.0-1
- upgrade to release 5.1.3

* Mon Mar 13 2017 Simon Matter <simon.matter@invoca.ch> 5.1.2.4-1
- upgrade to release 5.1.2.4

* Thu Mar 09 2017 Simon Matter <simon.matter@invoca.ch> 5.1.2.3-1
- upgrade to release 5.1.2.3

* Wed Mar 08 2017 Simon Matter <simon.matter@invoca.ch> 5.1.2.2-1
- upgrade to release 5.1.2.2

* Mon Mar 06 2017 Simon Matter <simon.matter@invoca.ch> 5.1.2.1-1
- upgrade to release 5.1.2.1

* Tue Jan 31 2017 Simon Matter <simon.matter@invoca.ch> 5.1.1.0-1
- upgrade to release 5.1.1

* Mon Jan 16 2017 Simon Matter <simon.matter@invoca.ch> 5.1.0.1-1
- upgrade to release 5.1.0.1

* Mon Jan 09 2017 Simon Matter <simon.matter@invoca.ch> 5.1.0.0-1
- upgrade to release 5.1.0

* Wed Dec 21 2016 Simon Matter <simon.matter@invoca.ch> 5.0.15.2-1
- upgrade to release 5.0.15.2

* Mon Dec 12 2016 Simon Matter <simon.matter@invoca.ch> 5.0.15.1-1
- upgrade to release 5.0.15.1

* Wed Dec 07 2016 Simon Matter <simon.matter@invoca.ch> 5.0.15.0-1
- upgrade to release 5.0.15

* Tue Nov 08 2016 Simon Matter <simon.matter@invoca.ch> 5.0.14.1-1
- upgrade to release 5.0.14.1

* Fri Nov 04 2016 Simon Matter <simon.matter@invoca.ch> 5.0.14.0-1
- upgrade to release 5.0.14

* Tue Oct 25 2016 Simon Matter <simon.matter@invoca.ch> 5.0.13.4-1
- upgrade to release 5.0.13.4

* Mon Oct 24 2016 Simon Matter <simon.matter@invoca.ch> 5.0.13.3-1
- upgrade to release 5.0.13.3

* Fri Oct 21 2016 Simon Matter <simon.matter@invoca.ch> 5.0.13.1-1
- upgrade to release 5.0.13.1

* Tue Oct 18 2016 Simon Matter <simon.matter@invoca.ch> 5.0.13.0-1
- upgrade to release 5.0.13

* Mon Oct 10 2016 Simon Matter <simon.matter@invoca.ch> 5.0.12.1-1
- upgrade to release 5.0.12.1

* Thu Oct 06 2016 Simon Matter <simon.matter@invoca.ch> 5.0.12.0-2
- move shorewallrc to -core package

* Mon Oct 03 2016 Simon Matter <simon.matter@invoca.ch> 5.0.12.0-1
- upgrade to release 5.0.12

* Sat Aug 13 2016 Simon Matter <simon.matter@invoca.ch> 5.0.11.0-1
- upgrade to release 5.0.11

* Sat Jul 16 2016 Simon Matter <simon.matter@invoca.ch> 5.0.10.1-1
- upgrade to release 5.0.10.1

* Sat Jul 02 2016 Simon Matter <simon.matter@invoca.ch> 5.0.10.0-1
- upgrade to release 5.0.10

* Tue Jun 14 2016 Simon Matter <simon.matter@invoca.ch> 5.0.9.2-1
- upgrade to release 5.0.9.2

* Mon Jun 13 2016 Simon Matter <simon.matter@invoca.ch> 5.0.9.1-1
- upgrade to release 5.0.9.1

* Mon Jun 06 2016 Simon Matter <simon.matter@invoca.ch> 5.0.9.0-1
- upgrade to release 5.0.9

* Tue May 03 2016 Simon Matter <simon.matter@invoca.ch> 5.0.8.2-1
- upgrade to release 5.0.8.2

* Mon May 02 2016 Simon Matter <simon.matter@invoca.ch> 5.0.8.1-1
- upgrade to release 5.0.8.1

* Mon Apr 25 2016 Simon Matter <simon.matter@invoca.ch> 5.0.8.0-1
- upgrade to release 5.0.8

* Thu Mar 31 2016 Simon Matter <simon.matter@invoca.ch> 5.0.7.2-1
- upgrade to release 5.0.7.2

* Tue Mar 29 2016 Simon Matter <simon.matter@invoca.ch> 5.0.7.1-1
- upgrade to release 5.0.7.1

* Thu Mar 17 2016 Simon Matter <simon.matter@invoca.ch> 5.0.6.2-1
- upgrade to release 5.0.6.2

* Thu Mar 10 2016 Simon Matter <simon.matter@invoca.ch> 5.0.6.1-1
- upgrade to release 5.0.6.1

* Wed Mar 09 2016 Simon Matter <simon.matter@invoca.ch> 5.0.6.0-1
- upgrade to release 5.0.6

* Mon Feb 29 2016 Simon Matter <simon.matter@invoca.ch> 5.0.5.1-1
- upgrade to release 5.0.5.1

* Mon Feb 22 2016 Simon Matter <simon.matter@invoca.ch> 5.0.5.0-1
- upgrade to release 5.0.5

* Fri Jan 22 2016 Simon Matter <simon.matter@invoca.ch> 5.0.4.0-1
- upgrade to release 5.0.4

* Mon Jan 04 2016 Simon Matter <simon.matter@invoca.ch> 5.0.3.1-1
- upgrade to release 5.0.3.1

* Sat Jan 02 2016 Simon Matter <simon.matter@invoca.ch> 5.0.3.0-1
- upgrade to release 5.0.3

* Fri Nov 27 2015 Simon Matter <simon.matter@invoca.ch> 5.0.2.1-1
- upgrade to release 5.0.2.1

* Mon Nov 16 2015 Simon Matter <simon.matter@invoca.ch> 5.0.2.0-1
- upgrade to release 5.0.2

* Wed Oct 28 2015 Simon Matter <simon.matter@invoca.ch> 5.0.1.1-1
- upgrade to release 5.0.1.1

* Tue Oct 13 2015 Simon Matter <simon.matter@invoca.ch> 5.0.1.0-1
- upgrade to release 5.0.1

* Mon Oct 12 2015 Simon Matter <simon.matter@invoca.ch> 5.0.0.0-1
- upgrade to release 5.0.0

* Mon Sep 21 2015 Simon Matter <simon.matter@invoca.ch> 4.6.13.1-1
- upgrade to release 4.6.13.1

* Tue Sep 08 2015 Simon Matter <simon.matter@invoca.ch> 4.6.13.0-1
- upgrade to release 4.6.13

* Mon Aug 24 2015 Simon Matter <simon.matter@invoca.ch> 4.6.12.1-1
- upgrade to release 4.6.12.1

* Fri Aug 21 2015 Simon Matter <simon.matter@invoca.ch> 4.6.12.0-1
- upgrade to release 4.6.12

* Tue Jul 21 2015 Simon Matter <simon.matter@invoca.ch> 4.6.11.1-1
- upgrade to release 4.6.11.1
- fix return value of status command in init scripts

* Thu Jun 11 2015 Simon Matter <simon.matter@invoca.ch> 4.6.10.1-1
- upgrade to release 4.6.10.1

* Mon Jun 01 2015 Simon Matter <simon.matter@invoca.ch> 4.6.10.0-1
- upgrade to release 4.6.10

* Thu May 07 2015 Simon Matter <simon.matter@invoca.ch> 4.6.9.0-1
- upgrade to release 4.6.9

* Mon Apr 13 2015 Simon Matter <simon.matter@invoca.ch> 4.6.8.1-1
- upgrade to release 4.6.8.1

* Sat Apr 04 2015 Simon Matter <simon.matter@invoca.ch> 4.6.8.0-1
- upgrade to release 4.6.8

* Thu Mar 12 2015 Simon Matter <simon.matter@invoca.ch> 4.6.7.0-1
- upgrade to release 4.6.7

* Mon Feb 09 2015 Simon Matter <simon.matter@invoca.ch> 4.6.6.2-1
- upgrade to release 4.6.6.2

* Mon Jan 26 2015 Simon Matter <simon.matter@invoca.ch> 4.6.6.1-3
- remove apply_sysctl from sysv init script

* Mon Jan 26 2015 Simon Matter <simon.matter@invoca.ch> 4.6.6.1-2
- add apply_sysctl to sysv init script

* Sat Jan 24 2015 Simon Matter <simon.matter@invoca.ch> 4.6.6.1-1
- upgrade to release 4.6.6.1

* Fri Jan 23 2015 Simon Matter <simon.matter@invoca.ch> 4.6.6.0-1
- upgrade to release 4.6.6
- add support for systemd

* Mon Jan 12 2015 Simon Matter <simon.matter@invoca.ch> 4.6.5.5-1
- upgrade to release 4.6.5.5

* Sat Jan 10 2015 Simon Matter <simon.matter@invoca.ch> 4.6.5.4-1
- upgrade to release 4.6.5.4

* Wed Dec 17 2014 Simon Matter <simon.matter@invoca.ch> 4.6.5.3-1
- upgrade to release 4.6.5.3

* Tue Nov 18 2014 Simon Matter <simon.matter@invoca.ch> 4.6.5.2-1
- upgrade to release 4.6.5.2

* Mon Nov 17 2014 Simon Matter <simon.matter@invoca.ch> 4.6.5.1-1
- upgrade to release 4.6.5.1

* Tue Oct 21 2014 Simon Matter <simon.matter@invoca.ch> 4.6.4.3-1
- upgrade to release 4.6.4.3

* Sun Oct 12 2014 Simon Matter <simon.matter@invoca.ch> 4.6.4.1-1
- upgrade to release 4.6.4.1

* Sat Oct 11 2014 Simon Matter <simon.matter@invoca.ch> 4.6.4.0-1
- upgrade to release 4.6.4

* Wed Sep 17 2014 Simon Matter <simon.matter@invoca.ch> 4.6.3.4-1
- upgrade to release 4.6.3.4

* Mon Sep 15 2014 Simon Matter <simon.matter@invoca.ch> 4.6.3.3-1
- upgrade to release 4.6.3.3

* Thu Sep 04 2014 Simon Matter <simon.matter@invoca.ch> 4.6.3.2-1
- upgrade to release 4.6.3.2

* Thu Aug 28 2014 Simon Matter <simon.matter@invoca.ch> 4.6.3.1-1
- upgrade to release 4.6.3.1

* Wed Aug 20 2014 Simon Matter <simon.matter@invoca.ch> 4.6.3.0-1
- upgrade to release 4.6.3

* Mon Aug 18 2014 Simon Matter <simon.matter@invoca.ch> 4.6.2.5-1
- upgrade to release 4.6.2.5

* Fri Aug 08 2014 Simon Matter <simon.matter@invoca.ch> 4.6.2.4-1
- upgrade to release 4.6.2.4

* Mon Jul 28 2014 Simon Matter <simon.matter@invoca.ch> 4.6.2.3-1
- upgrade to release 4.6.2.3

* Fri Jul 25 2014 Simon Matter <simon.matter@invoca.ch> 4.6.2.2-1
- upgrade to release 4.6.2.2

* Sat Jul 19 2014 Simon Matter <simon.matter@invoca.ch> 4.6.2.1-1
- upgrade to release 4.6.2.1

* Mon Jul 07 2014 Simon Matter <simon.matter@invoca.ch> 4.6.1.4-1
- upgrade to release 4.6.1.4

* Mon Jun 30 2014 Simon Matter <simon.matter@invoca.ch> 4.6.1.3-1
- upgrade to release 4.6.1.3

* Sat Jun 21 2014 Simon Matter <simon.matter@invoca.ch> 4.6.1.2-1
- upgrade to release 4.6.1.2

* Mon Jun 16 2014 Simon Matter <simon.matter@invoca.ch> 4.6.1.1-1
- upgrade to release 4.6.1.1

* Sat Jun 07 2014 Simon Matter <simon.matter@invoca.ch> 4.6.1.0-1
- upgrade to release 4.6.1

* Mon Jun 02 2014 Simon Matter <simon.matter@invoca.ch> 4.6.0.3-1
- upgrade to release 4.6.0.3

* Fri May 23 2014 Simon Matter <simon.matter@invoca.ch> 4.6.0.2-1
- upgrade to release 4.6.0.2

* Mon May 19 2014 Simon Matter <simon.matter@invoca.ch> 4.6.0.1-1
- upgrade to release 4.6.0.1

* Fri May 16 2014 Simon Matter <simon.matter@invoca.ch> 4.6.0.0-2
- add CHECKSUM patch

* Fri May 16 2014 Simon Matter <simon.matter@invoca.ch> 4.6.0.0-1
- upgrade to release 4.6.0

* Mon Mar 31 2014 Simon Matter <simon.matter@invoca.ch> 4.5.21.9-1
- upgrade to release 4.5.21.9

* Wed Mar 19 2014 Simon Matter <simon.matter@invoca.ch> 4.5.21.8-1
- upgrade to release 4.5.21.8

* Mon Mar 10 2014 Simon Matter <simon.matter@invoca.ch> 4.5.21.7-1
- upgrade to release 4.5.21.7

* Fri Jan 31 2014 Simon Matter <simon.matter@invoca.ch> 4.5.21.6-1
- upgrade to release 4.5.21.6

* Fri Dec 20 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21.5-1
- upgrade to release 4.5.21.5

* Mon Nov 25 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21.4-1
- upgrade to release 4.5.21.4

* Sat Oct 26 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21.3-1
- upgrade to release 4.5.21.3

* Tue Oct 22 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21.2-1
- upgrade to release 4.5.21.2

* Wed Oct 09 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21.1-1
- upgrade to release 4.5.21.1

* Mon Oct 07 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21-2
- add REAP patch

* Fri Oct 04 2013 Simon Matter <simon.matter@invoca.ch> 4.5.21-1
- upgrade to release 4.5.21

* Tue Aug 27 2013 Simon Matter <simon.matter@invoca.ch> 4.5.20-1
- upgrade to release 4.5.20

* Thu Jul 25 2013 Simon Matter <simon.matter@invoca.ch> 4.5.19-1
- upgrade to release 4.5.19

* Mon Jul 01 2013 Simon Matter <simon.matter@invoca.ch> 4.5.18-1
- upgrade to release 4.5.18

* Mon Jun 03 2013 Simon Matter <simon.matter@invoca.ch> 4.5.17.1-1
- upgrade to release 4.5.17.1

* Sat Jun 01 2013 Simon Matter <simon.matter@invoca.ch> 4.5.17.0-1
- upgrade to release 4.5.17

* Fri May 03 2013 Simon Matter <simon.matter@invoca.ch> 4.5.16.1-1
- upgrade to release 4.5.16.1

* Tue Apr 02 2013 Simon Matter <simon.matter@invoca.ch> 4.5.15.0-1
- upgrade to release 4.5.15

* Mon Mar 25 2013 Simon Matter <simon.matter@invoca.ch> 4.5.14.0-3
- remove build requirement for perl(Digest::SHA[1])

* Mon Mar 25 2013 Simon Matter <simon.matter@invoca.ch> 4.5.14.0-2
- add requirement for perl(Digest::SHA[1])

* Mon Mar 11 2013 Simon Matter <simon.matter@invoca.ch> 4.5.14.0-1
- upgrade to release 4.5.14

* Tue Feb 12 2013 Simon Matter <simon.matter@invoca.ch> 4.5.13.0-1
- upgrade to release 4.5.13

* Sat Jan 19 2013 Simon Matter <simon.matter@invoca.ch> 4.5.12.0-1
- upgrade to release 4.5.12

* Tue Jan 01 2013 Simon Matter <simon.matter@invoca.ch> 4.5.11.2-1
- upgrade to release 4.5.11.2

* Mon Dec 31 2012 Simon Matter <simon.matter@invoca.ch> 4.5.11.1-1
- upgrade to release 4.5.11.1

* Thu Dec 27 2012 Simon Matter <simon.matter@invoca.ch> 4.5.11.0-1
- upgrade to release 4.5.11

* Mon Dec 17 2012 Simon Matter <simon.matter@invoca.ch> 4.5.10.1-1
- upgrade to release 4.5.10.1

* Tue Dec 11 2012 Simon Matter <simon.matter@invoca.ch> 4.5.10-1
- upgrade to release 4.5.10

* Mon Nov 26 2012 Simon Matter <simon.matter@invoca.ch> 4.5.9.3-1
- upgrade to release 4.5.9.3

* Mon Nov 19 2012 Simon Matter <simon.matter@invoca.ch> 4.5.9.2-1
- upgrade to release 4.5.9.2

* Sat Nov 10 2012 Simon Matter <simon.matter@invoca.ch> 4.5.9.1-1
- upgrade to release 4.5.9.1

* Tue Oct 30 2012 Simon Matter <simon.matter@invoca.ch> 4.5.9-1
- upgrade to release 4.5.9

* Tue Oct 09 2012 Simon Matter <simon.matter@invoca.ch> 4.5.8.2-1
- upgrade to release 4.5.8.2

* Mon Oct 08 2012 Simon Matter <simon.matter@invoca.ch> 4.5.8.1-1
- upgrade to release 4.5.8.1

* Tue Sep 25 2012 Simon Matter <simon.matter@invoca.ch> 4.5.8-1
- upgrade to release 4.5.8

* Thu Aug 30 2012 Simon Matter <simon.matter@invoca.ch> 4.5.7.1-1
- upgrade to release 4.5.7.1

* Wed Aug 08 2012 Simon Matter <simon.matter@invoca.ch> 4.5.6.2-1
- upgrade to release 4.5.6.2

* Tue Jul 31 2012 Simon Matter <simon.matter@invoca.ch> 4.5.6.1-1
- upgrade to release 4.5.6.1

* Tue Jul 10 2012 Simon Matter <simon.matter@invoca.ch> 4.5.6-1
- upgrade to release 4.5.6

* Wed Jul 04 2012 Simon Matter <simon.matter@invoca.ch> 4.5.5.4-1
- upgrade to release 4.5.5.4

* Sat Jun 30 2012 Simon Matter <simon.matter@invoca.ch> 4.5.5.3-1
- upgrade to release 4.5.5.3

* Wed Jun 27 2012 Simon Matter <simon.matter@invoca.ch> 4.5.5.2-1
- upgrade to release 4.5.5.2

* Fri Jun 15 2012 Simon Matter <simon.matter@invoca.ch> 4.5.5.1-1
- upgrade to release 4.5.5.1

* Tue Jun 12 2012 Simon Matter <simon.matter@invoca.ch> 4.5.5-1
- upgrade to release 4.5.5

* Thu Jun 07 2012 Simon Matter <simon.matter@invoca.ch> 4.5.4.2-1
- upgrade to release 4.5.4.2

* Fri Jun 01 2012 Simon Matter <simon.matter@invoca.ch> 4.5.4.1-1
- upgrade to release 4.5.4.1

* Tue May 29 2012 Simon Matter <simon.matter@invoca.ch> 4.5.4-1
- upgrade to release 4.5.4

* Wed May 16 2012 Simon Matter <simon.matter@invoca.ch> 4.5.3.1-1
- upgrade to release 4.5.3.1

* Fri May 11 2012 Simon Matter <simon.matter@invoca.ch> 4.5.3-1
- upgrade to release 4.5.3

* Wed May 02 2012 Simon Matter <simon.matter@invoca.ch> 4.5.2.4-1
- upgrade to release 4.5.2.4

* Tue Apr 24 2012 Simon Matter <simon.matter@invoca.ch> 4.5.2.3-1
- upgrade to release 4.5.2.3

* Mon Apr 16 2012 Simon Matter <simon.matter@invoca.ch> 4.5.2.2-1
- upgrade to release 4.5.2.2

* Tue Apr 10 2012 Simon Matter <simon.matter@invoca.ch> 4.5.1.2-1
- upgrade to release 4.5.1.2

* Tue Mar 20 2012 Simon Matter <simon.matter@invoca.ch> 4.5.1.1-1
- upgrade to release 4.5.1.1

* Thu Mar 15 2012 Simon Matter <simon.matter@invoca.ch> 4.5.1-1
- upgrade to release 4.5.1

* Tue Mar 06 2012 Simon Matter <simon.matter@invoca.ch> 4.5.0.3-1
- upgrade to release 4.5.0.3

* Tue Feb 28 2012 Simon Matter <simon.matter@invoca.ch> 4.5.0.2-1
- upgrade to release 4.5.0.2

* Sun Feb 19 2012 Simon Matter <simon.matter@invoca.ch> 4.5.0.1-1
- upgrade to release 4.5.0.1

* Mon Feb 13 2012 Simon Matter <simon.matter@invoca.ch> 4.5.0-1
- upgrade to release 4.5.0
- add patch to fix LIBEXEC / PERLLIB
- add requirement for perl(Digest::SHA1)

* Mon Jan 23 2012 Simon Matter <simon.matter@invoca.ch> 4.4.27.3-1
- upgrade to release 4.4.27.3

* Sat Jan 14 2012 Simon Matter <simon.matter@invoca.ch> 4.4.27.2-1
- upgrade to release 4.4.27.2

* Sun Jan 08 2012 Simon Matter <simon.matter@invoca.ch> 4.4.27.1-1
- upgrade to release 4.4.27.1

* Fri Dec 30 2011 Simon Matter <simon.matter@invoca.ch> 4.4.27-1
- upgrade to release 4.4.27

* Mon Dec 19 2011 Simon Matter <simon.matter@invoca.ch> 4.4.26.1-1
- upgrade to release 4.4.26.1

* Sat Nov 12 2011 Simon Matter <simon.matter@invoca.ch> 4.4.25.3-1
- upgrade to release 4.4.25.3

* Sat Nov 05 2011 Simon Matter <simon.matter@invoca.ch> 4.4.25.2-1
- upgrade to release 4.4.25.2

* Tue Nov 01 2011 Simon Matter <simon.matter@invoca.ch> 4.4.25.1-1
- upgrade to release 4.4.25.1

* Tue Nov 01 2011 Simon Matter <simon.matter@invoca.ch> 4.4.25-1
- upgrade to release 4.4.25

* Mon Oct 17 2011 Simon Matter <simon.matter@invoca.ch> 4.4.24.1-1
- upgrade to release 4.4.24.1

* Mon Oct 10 2011 Simon Matter <simon.matter@invoca.ch> 4.4.24-1
- upgrade to release 4.4.24

* Sat Sep 17 2011 Simon Matter <simon.matter@invoca.ch> 4.4.23.3-1
- upgrade to release 4.4.23.3

* Wed Sep 14 2011 Simon Matter <simon.matter@invoca.ch> 4.4.23.2-1
- upgrade to release 4.4.23.2

* Fri Sep 09 2011 Simon Matter <simon.matter@invoca.ch> 4.4.23.1-1
- upgrade to release 4.4.23.1

* Wed Sep 07 2011 Simon Matter <simon.matter@invoca.ch> 4.4.23-1
- upgrade to release 4.4.23

* Mon Aug 22 2011 Simon Matter <simon.matter@invoca.ch> 4.4.22.3-1
- upgrade to release 4.4.22.3

* Wed Aug 10 2011 Simon Matter <simon.matter@invoca.ch> 4.4.22.2-2
- change defattr to fix directory permissions on EL6

* Tue Aug 09 2011 Simon Matter <simon.matter@invoca.ch> 4.4.22.2-1
- upgrade to release 4.4.22.2

* Wed Aug 03 2011 Simon Matter <simon.matter@invoca.ch> 4.4.22.1-1
- upgrade to release 4.4.22.1

* Tue Aug 02 2011 Simon Matter <simon.matter@invoca.ch> 4.4.22-1
- upgrade to release 4.4.22

* Wed Jul 20 2011 Simon Matter <simon.matter@invoca.ch> 4.4.21.1-1
- upgrade to release 4.4.21.1

* Wed Jul 13 2011 Simon Matter <simon.matter@invoca.ch> 4.4.21-1
- upgrade to release 4.4.21

* Wed Jun 15 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20.3-1
- upgrade to release 4.4.20.3

* Wed Jun 15 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20.2-2
- add sfilter patches

* Sat Jun 11 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20.2-1
- upgrade to release 4.4.20.2

* Wed Jun 08 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20.1-2
- do not annotate configs

* Tue Jun 07 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20.1-1
- upgrade to release 4.4.20.1

* Mon Jun 06 2011 Simon Matter <simon.matter@invoca.ch> 4.4.20-1
- upgrade to release 4.4.20

* Wed May 18 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19.4-1
- upgrade to release 4.4.19.4

* Thu May 12 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19.3-1
- upgrade to release 4.4.19.3

* Mon May 09 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19.2-1
- upgrade to release 4.4.19.2

* Sat Apr 16 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19.1-1
- upgrade to release 4.4.19.1

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19-3
- mass rebuild

* Thu Apr 14 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19-2
- spec changes

* Wed Apr 13 2011 Simon Matter <simon.matter@invoca.ch> 4.4.19-1
- upgrade to release 4.4.19

* Mon Apr 04 2011 Simon Matter <simon.matter@invoca.ch> 4.4.18.2-1
- upgrade to release 4.4.18.2

* Mon Mar 21 2011 Simon Matter <simon.matter@invoca.ch> 4.4.18.1-1
- upgrade to release 4.4.18.1

* Fri Mar 11 2011 Simon Matter <simon.matter@invoca.ch> 4.4.18-1
- upgrade to release 4.4.18

* Thu Feb 10 2011 Simon Matter <simon.matter@invoca.ch> 4.4.17-1
- upgrade to release 4.4.17

* Thu Jan 20 2011 Simon Matter <simon.matter@invoca.ch> 4.4.16.1-1
- upgrade to release 4.4.16.1

* Wed Jan 12 2011 Simon Matter <simon.matter@invoca.ch> 4.4.16-1
- upgrade to release 4.4.16

* Wed Dec 29 2010 Simon Matter <simon.matter@invoca.ch> 4.4.15.3-1
- upgrade to release 4.4.15.3

* Mon Dec 20 2010 Simon Matter <simon.matter@invoca.ch> 4.4.15.2-1
- upgrade to release 4.4.15.2

* Fri Dec 03 2010 Simon Matter <simon.matter@invoca.ch> 4.4.15.1-1
- upgrade to release 4.4.15.1

* Thu Dec 02 2010 Simon Matter <simon.matter@invoca.ch> 4.4.15-1
- upgrade to release 4.4.15

* Fri Oct 29 2010 Simon Matter <simon.matter@invoca.ch> 4.4.14-1
- upgrade to release 4.4.14

* Mon Oct 04 2010 Simon Matter <simon.matter@invoca.ch> 4.4.13.3-1
- upgrade to release 4.4.13.3

* Mon Sep 27 2010 Simon Matter <simon.matter@invoca.ch> 4.4.13.1-1
- upgrade to release 4.4.13.1

* Wed Sep 22 2010 Simon Matter <simon.matter@invoca.ch> 4.4.13-1
- upgrade to release 4.4.13

* Mon Sep 06 2010 Simon Matter <simon.matter@invoca.ch> 4.4.12.2-1
- upgrade to release 4.4.12.2

* Wed Aug 25 2010 Simon Matter <simon.matter@invoca.ch> 4.4.12.1-1
- upgrade to release 4.4.12.1

* Fri Aug 20 2010 Simon Matter <simon.matter@invoca.ch> 4.4.12-1
- upgrade to release 4.4.12

* Tue Aug 10 2010 Simon Matter <simon.matter@invoca.ch> 4.4.11.2-1
- upgrade to release 4.4.11.2

* Tue Jul 27 2010 Simon Matter <simon.matter@invoca.ch> 4.4.11.1-1
- upgrade to release 4.4.11.1

* Fri Jul 16 2010 Simon Matter <simon.matter@invoca.ch> 4.4.11-1
- upgrade to release 4.4.11

* Tue Jul 06 2010 Simon Matter <simon.matter@invoca.ch> 4.4.10.3-1
- upgrade to release 4.4.10.3

* Sat Jun 26 2010 Simon Matter <simon.matter@invoca.ch> 4.4.10.2-1
- upgrade to release 4.4.10.2

* Sat Jun 19 2010 Simon Matter <simon.matter@invoca.ch> 4.4.10-2
- remove debug output from shorewall-init init script

* Fri Jun 18 2010 Simon Matter <simon.matter@invoca.ch> 4.4.10-1
- upgrade to release 4.4.10

* Sat May 08 2010 Simon Matter <simon.matter@invoca.ch> 4.4.9-1
- upgrade to release 4.4.9

* Sat Apr 24 2010 Simon Matter <simon.matter@invoca.ch> 4.4.8-5
- add patch-4.4.8.4
- add patch-6-4.4.8.4
- add patch-6-lite-4.4.8.4
- add patch-lite-4.4.8.4

* Wed Apr 21 2010 Simon Matter <simon.matter@invoca.ch> 4.4.8-4
- add patch-4.4.8.3
- add patch-6-4.4.8.3
- add patch-6-lite-4.4.8.3
- add patch-lite-4.4.8.3

* Wed Apr 14 2010 Simon Matter <simon.matter@invoca.ch> 4.4.8-3
- add patch-4.4.8.2
- add patch-6-4.4.8.2
- add patch-6-lite-4.4.8.2
- add patch-lite-4.4.8.2

* Fri Apr 09 2010 Simon Matter <simon.matter@invoca.ch> 4.4.8-2
- add patch-4.4.8.1
- add patch-6-4.4.8.1

* Thu Mar 25 2010 Simon Matter <simon.matter@invoca.ch> 4.4.8-1
- upgrade to release 4.4.8

* Fri Mar 12 2010 Simon Matter <simon.matter@invoca.ch> 4.4.7-2
- add patch-4.4.7.6

* Wed Feb 24 2010 Simon Matter <simon.matter@invoca.ch> 4.4.7-1
- upgrade to release 4.4.7

* Sat Jan 16 2010 Simon Matter <simon.matter@invoca.ch> 4.4.6-1
- upgrade to release 4.4.6

* Mon Dec 28 2009 Simon Matter <simon.matter@invoca.ch> 4.4.5-4
- add patch-4.4.5.4
- add patch-6-4.4.5.4
- add patch-6-lite-4.4.5.4
- add patch-lite-4.4.5.4

* Thu Dec 24 2009 Simon Matter <simon.matter@invoca.ch> 4.4.5-3
- add patch-4.4.5.3

* Mon Dec 21 2009 Simon Matter <simon.matter@invoca.ch> 4.4.5-2
- add patch-4.4.5.1
- add patch-4.4.5.2

* Sat Dec 19 2009 Simon Matter <simon.matter@invoca.ch> 4.4.5-1
- upgrade to release 4.4.5

* Mon Dec 07 2009 Simon Matter <simon.matter@invoca.ch> 4.4.4-3
- add patch-4.4.4.2
- add patch-6-4.4.4.2
- add patch-6-lite-4.4.4.2

* Mon Nov 23 2009 Simon Matter <simon.matter@invoca.ch> 4.4.4-2
- add patch-4.4.4.1

* Sat Nov 21 2009 Simon Matter <simon.matter@invoca.ch> 4.4.4-1
- upgrade to release 4.4.4

* Thu Nov 12 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-6
- add logrotate to requires

* Thu Nov 05 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-5
- add logrotate patch

* Wed Nov 04 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-4
- preserve timestamps on install

* Wed Nov 04 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-3
- replace create-startup_log patch and logrotate script with upstream patch

* Tue Nov 03 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-2
- add create-startup_log patch
- add logrotate script for startup log

* Mon Nov 02 2009 Simon Matter <simon.matter@invoca.ch> 4.4.3-1
- upgrade to release 4.4.3

* Mon Oct 26 2009 Simon Matter <simon.matter@invoca.ch> 4.4.2-3
- add patch-4.4.2.4

* Mon Oct 19 2009 Simon Matter <simon.matter@invoca.ch> 4.4.2-2
- add patch-4.4.2.3

* Mon Oct 05 2009 Simon Matter <simon.matter@invoca.ch> 4.4.2-1
- upgrade to release 4.4.2
- add patch-4.4.2.1
- add patch-4.4.2.2

* Fri Sep 04 2009 Simon Matter <simon.matter@invoca.ch> 4.4.1-1
- upgrade to release 4.4.1
- add patch-4.4.1.1
- add patch-4.4.1.2

* Mon Aug 31 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-3
- add patch-4.4.0.2

* Thu Aug 27 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-2
- add patch-4.4.0.1

* Sat Aug 15 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-1
- upgrade to release 4.4.0

* Mon Aug 03 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.RC2_1
- upgrade to release 4.4.0-RC2

* Mon Jul 27 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.RC1_1
- upgrade to release 4.4.0-RC1

* Mon Jul 13 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.Beta4_1
- upgrade to release 4.4.0-Beta4

* Wed Jul 01 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.Beta3_1
- upgrade to release 4.4.0-Beta3

* Mon Jun 22 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.Beta2_1
- upgrade to release 4.4.0-Beta2

* Mon Jun 15 2009 Simon Matter <simon.matter@invoca.ch> 4.4.0-0.Beta1_1
- upgrade to release 4.4.0-Beta1

* Fri May 15 2009 Simon Matter <simon.matter@invoca.ch> 4.2.9-1
- upgrade to release 4.2.9

* Tue May 12 2009 Simon Matter <simon.matter@invoca.ch> 4.2.8-4
- use more macros in spec file

* Wed Apr 22 2009 Simon Matter <simon.matter@invoca.ch> 4.2.8-3
- add patch-perl-4.2.8.2

* Fri Apr 17 2009 Simon Matter <simon.matter@invoca.ch> 4.2.8-2
- add patch-perl-4.2.8.1

* Fri Apr 17 2009 Simon Matter <simon.matter@invoca.ch> 4.2.8-1
- upgrade to release 4.2.8

* Mon Apr 13 2009 Simon Matter <simon.matter@invoca.ch> 4.2.7-4
- add patch-perl-4.2.7.3

* Mon Apr 06 2009 Simon Matter <simon.matter@invoca.ch> 4.2.7-3
- add patch-perl-4.2.7.2

* Fri Apr 03 2009 Simon Matter <simon.matter@invoca.ch> 4.2.7-2
- add patch-perl-4.2.7.1

* Fri Mar 20 2009 Simon Matter <simon.matter@invoca.ch> 4.2.7-1
- upgrade to release 4.2.7

* Thu Mar 05 2009 Simon Matter <simon.matter@invoca.ch> 4.2.6-3
- add patch-perl-4.2.6.2

* Sat Feb 28 2009 Simon Matter <simon.matter@invoca.ch> 4.2.6-2
- add patch-perl-4.2.6.1

* Sun Feb 15 2009 Simon Matter <simon.matter@invoca.ch> 4.2.6-1
- upgrade to release 4.2.6

* Mon Feb 09 2009 Simon Matter <simon.matter@invoca.ch> 4.2.5-4
- add patch-perl-4.2.5.3

* Sat Feb 07 2009 Simon Matter <simon.matter@invoca.ch> 4.2.5-3
- add patch-perl-4.2.5.2

* Sun Feb 01 2009 Simon Matter <simon.matter@invoca.ch> 4.2.5-2
- add patch-perl-4.2.5.1
- add patch-6-4.2.5.1

* Thu Jan 22 2009 Simon Matter <simon.matter@invoca.ch> 4.2.5-1
- upgrade to release 4.2.5

* Wed Jan 14 2009 Simon Matter <simon.matter@invoca.ch> 4.2.4-5
- add patch-perl-4.2.4.6

* Fri Jan 02 2009 Simon Matter <simon.matter@invoca.ch> 4.2.4-4
- add patch-perl-4.2.4.5

* Thu Jan 01 2009 Simon Matter <simon.matter@invoca.ch> 4.2.4-3
- add patch-perl-4.2.4.2
- add patch-perl-4.2.4.3
- add patch-perl-4.2.4.4

* Wed Dec 31 2008 Simon Matter <simon.matter@invoca.ch> 4.2.4-2
- upgrade to release 4.2.4
- add patch-6-4.2.4.1
- add patch-6-lite-4.2.4.1
- add patch-perl-4.2.4.1

* Mon Dec 29 2008 Simon Matter <simon.matter@invoca.ch> 4.2.4-0.RC3_1
- upgrade to release 4.2.4-RC3

* Tue Dec 23 2008 Simon Matter <simon.matter@invoca.ch> 4.2.4-0.RC2_1
- upgrade to release 4.2.4-RC2

* Sat Dec 20 2008 Simon Matter <simon.matter@invoca.ch> 4.2.4-0.RC1_1
- upgrade to release 4.2.4-RC1

* Tue Dec 16 2008 Simon Matter <simon.matter@invoca.ch> 4.2.3-1
- upgrade to release 4.2.3

* Sat Dec 06 2008 Simon Matter <simon.matter@invoca.ch> 4.2.2-2
- add patch-common-4.2.2.1
- add patch-lite-4.2.2.1
- add patch-perl-4.2.2.1
- add patch-perl-4.2.2.2

* Fri Nov 21 2008 Simon Matter <simon.matter@invoca.ch> 4.2.2-1
- upgrade to release 4.2.2

* Thu Oct 30 2008 Simon Matter <simon.matter@invoca.ch> 4.2.1-2
- add patch-perl-4.2.1.1

* Mon Oct 27 2008 Simon Matter <simon.matter@invoca.ch> 4.2.1-1
- upgrade to release 4.2.1

* Mon Oct 06 2008 Simon Matter <simon.matter@invoca.ch> 4.2.0-1
- upgrade to release 4.2.0

* Tue Sep 23 2008 Simon Matter <simon.matter@invoca.ch> 4.0.14-1
- upgrade to release 4.0.14

* Thu Sep 11 2008 Simon Matter <simon.matter@invoca.ch> 4.0.13-2
- add patch-shell-4.0.13.1

* Mon Jul 28 2008 Simon Matter <simon.matter@invoca.ch> 4.0.13-1
- upgrade to release 4.0.13
- remove -f as default start option in the init script

* Mon Jun 30 2008 Simon Matter <simon.matter@invoca.ch> 4.0.12-1
- upgrade to release 4.0.12
- add patch-perl-4.0.12.1

* Thu Jun 12 2008 Simon Matter <simon.matter@invoca.ch> 4.0.11-2
- add patch-perl-4.0.11.1

* Tue May 20 2008 Simon Matter <simon.matter@invoca.ch> 4.0.11-1
- upgrade to release 4.0.11

* Sun Apr 20 2008 Simon Matter <simon.matter@invoca.ch> 4.0.10-3
- remove patch-common-4.0.10-1.diff
- add patch-common-4.0.10.1
- add patch-perl-4.0.10.1

* Sat Apr 19 2008 Simon Matter <simon.matter@invoca.ch> 4.0.10-2
- add patch-common-4.0.10-1.diff

* Sat Mar 29 2008 Simon Matter <simon.matter@invoca.ch> 4.0.10-1
- upgrade to release 4.0.10

* Mon Mar 03 2008 Simon Matter <simon.matter@invoca.ch> 4.0.9-3
- add patch-shell-4.0.9.1

* Wed Feb 27 2008 Simon Matter <simon.matter@invoca.ch> 4.0.9-2
- add patch-perl-4.0.9.1

* Sat Feb 23 2008 Simon Matter <simon.matter@invoca.ch> 4.0.9-1
- upgrade to release 4.0.9

* Sun Feb 17 2008 Simon Matter <simon.matter@invoca.ch> 4.0.8-4
- add patch-perl-4.0.8.3

* Thu Feb 07 2008 Simon Matter <simon.matter@invoca.ch> 4.0.8-3
- add patch-perl-4.0.8.2

* Mon Feb 04 2008 Simon Matter <simon.matter@invoca.ch> 4.0.8-2
- add patch-perl-4.0.8.1

* Sat Jan 26 2008 Simon Matter <simon.matter@invoca.ch> 4.0.8-1
- upgrade to release 4.0.8

* Mon Jan 14 2008 Simon Matter <simon.matter@invoca.ch> 4.0.7-5
- add patch-perl-4.0.7.3

* Sun Jan 06 2008 Simon Matter <simon.matter@invoca.ch> 4.0.7-4
- change to new release patches
- add patch-perl-4.0.7.1
- add patch-perl-4.0.7.2
- add patch-shell-4.0.7.2

* Wed Jan 02 2008 Simon Matter <simon.matter@invoca.ch> 4.0.7-3
- add patch-perl-4.0.7-2.diff from errata

* Sun Dec 30 2007 Simon Matter <simon.matter@invoca.ch> 4.0.7-2
- add patch-perl-4.0.7-1.diff from errata

* Thu Dec 27 2007 Simon Matter <simon.matter@invoca.ch> 4.0.7-1
- upgrade to release 4.0.7

* Sun Dec 16 2007 Simon Matter <simon.matter@invoca.ch> 4.0.6-3
- add patch-shell-4.0.6-1.diff from errata

* Sun Dec 09 2007 Simon Matter <simon.matter@invoca.ch> 4.0.6-2
- add patch-perl-4.0.6-2.diff from errata
- add patch-perl-4.0.6-3.diff from errata

* Sat Nov 24 2007 Simon Matter <simon.matter@invoca.ch> 4.0.6-1
- upgrade to release 4.0.6

* Sat Nov 17 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-7
- add patch-perl-4.0.5-5.diff from errata

* Thu Nov 08 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-6
- relax file permissions

* Wed Nov 07 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-5
- upgrade patch-perl-4.0.5-4.diff from errata
- upgrade patch-shell-4.0.5-1.diff from errata

* Tue Oct 30 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-4
- upgrade patch-perl-4.0.5-3.diff from errata

* Wed Oct 24 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-3
- add patch-perl-4.0.5-3.diff from errata

* Tue Oct 23 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-2
- add patch-perl-4.0.5-1.diff from errata
- add patch-perl-4.0.5-2.diff from errata

* Mon Oct 22 2007 Simon Matter <simon.matter@invoca.ch> 4.0.5-1
- upgrade to release 4.0.5
- remove buildports_on_the_fly patch

* Thu Oct 11 2007 Simon Matter <simon.matter@invoca.ch> 4.0.4-2
- add patch-perl-4.0.5-1.diff from errata

* Thu Sep 27 2007 Simon Matter <simon.matter@invoca.ch> 4.0.4-1
- upgrade to release 4.0.4

* Wed Sep 19 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-6
- add all updated patches from errata

* Sat Sep 15 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-5
- add patch-perl-4.0.3-4.diff from errata
- add patch-perl-4.0.3-3b.diff

* Tue Sep 04 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-4
- add patch-perl-4.0.3-2.diff from errata
- add patch-perl-4.0.3-3.diff from errata

* Mon Sep 03 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-3
- add patch-common-4.0.3-1.diff from errata

* Mon Sep 03 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-2
- add patch-perl-4.0.3-1.diff from errata

* Sat Sep 01 2007 Simon Matter <simon.matter@invoca.ch> 4.0.3-1
- upgrade to release 4.0.3

* Thu Aug 30 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-7
- add patch-perl-4.0.2-2.diff from errata

* Tue Aug 28 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-6
- move continue files from shorewall to shorewall-shell

* Wed Aug 22 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-5
- add patch-shell-4.0.2-2.diff from errata

* Tue Aug 21 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-4
- add patch-perl-4.0.2-1.diff from errata

* Fri Aug 17 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-3
- add patch-common-4.0.2-1.diff from errata
- add patch-lite-4.0.2-1.diff from errata

* Tue Aug 14 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-2
- add patch-shell-4.0.2-1.diff from errata

* Fri Aug 10 2007 Simon Matter <simon.matter@invoca.ch> 4.0.2-1
- upgrade to release 4.0.2

* Fri Aug 10 2007 Simon Matter <simon.matter@invoca.ch> 4.0.1-5
- add patch-perl-4.0.1-5.diff from errata

* Tue Aug 07 2007 Simon Matter <simon.matter@invoca.ch> 4.0.1-4
- add patch-perl-4.0.1-4.diff from errata

* Mon Aug 06 2007 Simon Matter <simon.matter@invoca.ch> 4.0.1-3
- add patch-perl-4.0.1-3.diff from errata
- add patch-shell-4.0.1-1.diff from errata
- add patch-common-4.0.1-1.diff from errata

* Wed Aug 01 2007 Simon Matter <simon.matter@invoca.ch> 4.0.1-2
- add patch-perl-4.0.1-1.diff from errata

* Mon Jul 30 2007 Simon Matter <simon.matter@invoca.ch> 4.0.1-1
- upgrade to release 4.0.1

* Mon Jul 30 2007 Simon Matter <simon.matter@invoca.ch> 4.0.0-5
- add patch-perl-4.0.0-6.diff from errata

* Sat Jul 28 2007 Simon Matter <simon.matter@invoca.ch> 4.0.0-4
- add patch-perl-4.0.0-5.diff from errata

* Sat Jul 28 2007 Simon Matter <simon.matter@invoca.ch> 4.0.0-3
- add patch-perl-4.0.0-4.diff from errata

* Thu Jul 26 2007 Simon Matter <simon.matter@invoca.ch> 4.0.0-2
- add patch-perl-4.0.0-2.diff from errata
- add patch-perl-4.0.0-3.diff from errata
- add patch-shell-4.0.0-1.diff from errata

* Wed Jul 25 2007 Simon Matter <simon.matter@invoca.ch> 4.0.0-1
- upgrade to release 4.0.0

* Mon Jul 16 2007 Simon Matter <simon.matter@invoca.ch> 3.4.5-1
- upgrade to release 3.4.5

* Tue Jul 10 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-8
- add updated patch-3.4.4-5.diff from errata

* Wed Jul 04 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-7
- add patch-3.4.4-6.diff from errata

* Tue Jul 03 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-6
- add patch-3.4.4-5.diff from errata

* Tue Jul 03 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-5
- add patch-3.4.4-4.diff from errata

* Sun Jul 01 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-4
- add patch-3.4.4-3.diff from errata

* Mon Jun 25 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-3
- add patch-3.4.4-2.diff from errata

* Thu Jun 21 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-2
- add patch-3.4.4-1.diff from errata

* Mon Jun 18 2007 Simon Matter <simon.matter@invoca.ch> 3.4.4-1
- upgrade to release 3.4.4

* Tue May 29 2007 Simon Matter <simon.matter@invoca.ch> 3.4.3-1
- upgrade to release 3.4.3

* Tue Apr 17 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-6
- add patch-3.4.2-6.diff from errata

* Mon Apr 16 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-5
- add patch-3.4.2-5.diff from errata
- add patch-lite-3.4.2-2.diff from errata (renamed)

* Sun Apr 15 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-4
- add patch-3.4.2-4.diff from errata

* Tue Apr 10 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-3
- add patch-3.4.2-1.diff from errata (updated patch)
- add patch-3.4.2-2.diff from errata
- add patch-3.4.2-3.diff from errata

* Sat Apr 07 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-2
- add patch-3.4.2-1.diff from errata
- add patch-lite-3.4.2-1.diff from errata (renamed)

* Mon Apr 02 2007 Simon Matter <simon.matter@invoca.ch> 3.4.2-1
- upgrade to release 3.4.2

* Fri Mar 23 2007 Simon Matter <simon.matter@invoca.ch> 3.4.1-3
- add patch-3.4.1-3.diff from errata
- add patch-3.4.1-4.diff from errata

* Tue Mar 20 2007 Simon Matter <simon.matter@invoca.ch> 3.4.1-2
- add patch-3.4.1-1.diff from errata
- add patch-3.4.1-2.diff from errata

* Fri Mar 16 2007 Simon Matter <simon.matter@invoca.ch> 3.4.1-1
- upgrade to release 3.4.1

* Thu Mar 15 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-3
- add patch-3.4.0-6.diff from errata

* Wed Mar 14 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-2
- add patch-3.4.0-3.diff from errata
- add patch-3.4.0-4.diff from errata
- add patch-3.4.0-5.diff from errata

* Mon Mar 12 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-1
- upgrade to release 3.4.0
- add patch-3.4.0-1.diff from errata
- add patch-3.4.0-2.diff from errata

* Sun Feb 25 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC3_1
- upgrade to release 3.4.0-RC3

* Wed Feb 21 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC2_3
- add patch-3.4.0-RC2-2.diff from errata
- add patch-3.4.0-RC2-3.diff from errata

* Sat Feb 17 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC2_2
- add patch-3.4.0-RC2-1.diff from errata

* Mon Feb 12 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC2_1
- upgrade to release 3.4.0-RC2

* Mon Feb 05 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC1_2
- add patch-3.4.0-RC1-1.diff from errata

* Fri Feb 02 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.RC1_1
- upgrade to release 3.4.0-RC1

* Tue Jan 23 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.Beta3_1
- upgrade to release 3.4.0-Beta3

* Mon Jan 22 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.Beta2_2
- fix permissions

* Fri Jan 05 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.Beta2_1
- upgrade to release 3.4.0-Beta2

* Wed Jan 03 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.Beta1_2
- fix manpages in -lite

* Tue Jan 02 2007 Simon Matter <simon.matter@invoca.ch> 3.4.0-0.Beta1_1
- upgrade to release 3.4.0-Beta1

* Sat Dec 30 2006 Simon Matter <simon.matter@invoca.ch> 3.2.7-3
- add patch-3.2.7-1.diff from errata, replacing 3.2.7-patch-1.diff
- add patch-3.2.7-2.diff from errata

* Wed Dec 27 2006 Simon Matter <simon.matter@invoca.ch> 3.2.7-2
- add 3.2.7-patch-1.diff from errata

* Thu Dec 14 2006 Simon Matter <simon.matter@invoca.ch> 3.2.7-1
- upgrade to release 3.2.7

* Sat Nov 25 2006 Simon Matter <simon.matter@invoca.ch> 3.2.6-2
- add patch-3.2.6-1.diff from errata

* Sun Nov 19 2006 Simon Matter <simon.matter@invoca.ch> 3.2.6-1
- upgrade to release 3.2.6

* Thu Nov 16 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-7
- add patch-3.2.5-6.diff from errata
- add patch-3.2.5-7.diff from errata
- add patch-3.2.5-8.diff from errata

* Tue Nov 14 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-6
- add patch-3.2.5-5.diff from errata

* Fri Nov 10 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-5
- add patch-3.2.5-4.diff from errata

* Wed Nov 08 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-4
- add patch-3.2.5-3.diff from errata
- remove patch-3.2.5-1.diff, it's included in 3.2.5-3

* Thu Nov 02 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-3
- add updates from errata

* Sun Oct 29 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-2
- add updates from errata

* Sat Oct 28 2006 Simon Matter <simon.matter@invoca.ch> 3.2.5-1
- upgrade to release 3.2.5

* Thu Oct 19 2006 Simon Matter <simon.matter@invoca.ch> 3.2.4-5
- add updates from errata

* Thu Oct 12 2006 Simon Matter <simon.matter@invoca.ch> 3.2.4-4
- add updates from errata

* Wed Oct 11 2006 Simon Matter <simon.matter@invoca.ch> 3.2.4-3
- add updates from errata

* Wed Oct 04 2006 Simon Matter <simon.matter@invoca.ch> 3.2.4-2
- add updates from errata
- change Prereq to new style

* Fri Sep 29 2006 Simon Matter <simon.matter@invoca.ch> 3.2.4-1
- upgrade to release 3.2.4

* Wed Sep 06 2006 Simon Matter <simon.matter@invoca.ch> 3.2.3-2
- add exec_test patch

* Mon Aug 28 2006 Simon Matter <simon.matter@invoca.ch> 3.2.3-1
- upgrade to release 3.2.3

* Thu Aug 24 2006 Simon Matter <simon.matter@invoca.ch> 3.2.2-4
- add updated firewall script

* Fri Aug 18 2006 Simon Matter <simon.matter@invoca.ch> 3.2.2-3
- add updates from errata

* Sat Aug 12 2006 Simon Matter <simon.matter@invoca.ch> 3.2.2-2
- add updated shorewall.conf

* Thu Aug 10 2006 Simon Matter <simon.matter@invoca.ch> 3.2.2-1
- upgrade to release 3.2.2

* Fri Jul 21 2006 Simon Matter <simon.matter@invoca.ch> 3.2.1-1
- upgrade to release 3.2.1

* Thu Jul 20 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-2
- add install patch to fix wrong xmodules being installed

* Wed Jul 12 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-1
- upgrade to release 3.2.0

* Sat Jul 01 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC6_1
- update to 3.2.0-RC6

* Mon Jun 26 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC5_1
- update to 3.2.0-RC5

* Tue Jun 20 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC4_2
- add shorewall file from errata

* Mon Jun 19 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC4_1
- update to 3.2.0-RC4

* Fri Jun 16 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC3_1
- update to 3.2.0-RC3
- include -lite as subpackage

* Wed Jun 07 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.RC1_1
- update to 3.2.0-RC1

* Mon May 29 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta8_1
- update to 3.2.0-Beta8

* Wed May 17 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta7_1
- update to 3.2.0-Beta7

* Mon May 08 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta6_1
- update to 3.2.0-Beta6

* Thu Apr 27 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta5_1
- update to 3.2.0-Beta5

* Thu Apr 13 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta4_2
- add compiler file from errata

* Thu Apr 06 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta4_1
- update to 3.2.0-Beta4

* Tue Mar 28 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta3_1
- update to 3.2.0-Beta3

* Fri Mar 24 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta2_1
- update to 3.2.0-Beta2

* Sat Mar 11 2006 Simon Matter <simon.matter@invoca.ch> 3.2.0-0.Beta1_1
- update to 3.2.0-Beta1

* Mon Mar 06 2006 Simon Matter <simon.matter@invoca.ch> 3.1.9-1
- update to 3.1.9

* Thu Mar 02 2006 Simon Matter <simon.matter@invoca.ch> 3.1.8-1
- add compiler file from errata

* Wed Mar 01 2006 Simon Matter <simon.matter@invoca.ch> 3.1.8-0
- update to 3.1.8

* Tue Feb 14 2006 Simon Matter <simon.matter@invoca.ch> 3.0.5-2
- fix download path

* Mon Feb 13 2006 Simon Matter <simon.matter@invoca.ch> 3.0.5-1
- update to 3.0.5

* Mon Jan 16 2006 Simon Matter <simon.matter@invoca.ch> 3.0.4-2
- add firewall script from errata

* Thu Jan 05 2006 Simon Matter <simon.matter@invoca.ch> 3.0.4-1
- update to 3.0.4

* Wed Dec 14 2005 Simon Matter <simon.matter@invoca.ch> 3.0.3-1
- update to 3.0.3

* Wed Nov 30 2005 Simon Matter <simon.matter@invoca.ch> 3.0.2-1
- update to 3.0.2

* Fri Nov 18 2005 Simon Matter <simon.matter@invoca.ch> 3.0.1-1
- update to 3.0.1

* Thu Nov 17 2005 Simon Matter <simon.matter@invoca.ch> 3.0.0-3
- remove redundant chmod from spec
- add Makefile from errata

* Mon Nov 14 2005 Simon Matter <simon.matter@invoca.ch> 3.0.0-2
- add firewall script from errata

* Fri Nov 11 2005 Simon Matter <simon.matter@invoca.ch> 3.0.0-1
- update to 3.0.0

* Thu Nov 03 2005 Simon Matter <simon.matter@invoca.ch> 3.0.0-0.RC3_1
- update to 3.0.0-RC3

* Mon Oct 24 2005 Simon Matter <simon.matter@invoca.ch> 3.0.0-0.RC2_1
- update to 3.0.0-RC2

* Thu Oct 06 2005 Simon Matter <simon.matter@invoca.ch> 2.4.5-1
- update to 2.4.5
- add firewall script from errata

* Fri Sep 16 2005 Simon Matter <simon.matter@invoca.ch> 2.4.4-1
- updated to 2.4.4
- add firewall script from errata

* Wed Aug 17 2005 Simon Matter <simon.matter@invoca.ch> 2.4.3-1
- updated to 2.4.3
- removed which to requires

* Fri Jul 22 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.4.2

* Mon Jul 18 2005 Simon Matter <simon.matter@invoca.ch>
- updated firewall script

* Thu Jul 14 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.4.1

* Tue Jun 07 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.4.0

* Sat May 21 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.5

* Tue May 03 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.4

* Fri Apr 08 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.3

* Sun Mar 27 2005 Simon Matter <simon.matter@invoca.ch>
- added errata file

* Sat Mar 19 2005 Marek Gilbert <gil@fooplanet.com>
- fixed install on x86_64

* Mon Mar 14 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.2

* Mon Feb 28 2005 Simon Matter <simon.matter@invoca.ch>
- added /etc/redhat-release to prerequires

* Wed Feb 16 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.1

* Wed Feb 02 2005 Simon Matter <simon.matter@invoca.ch>
- added which to requires
- added errata files
- modified directory permissions
- added umask patch

* Wed Jan 26 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.0 (Take 2)

* Tue Jan 25 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.0

* Mon Jan 17 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.0-RC5

* Fri Jan 07 2005 Simon Matter <simon.matter@invoca.ch>
- updated to 2.2.0-RC4

* Fri Dec 31 2004 Simon Matter <simon.matter@invoca.ch>
- initial public release
